Stacked Widget (stackedwidget) — Orange Canvas Core 0.0.9 documentation

# Orange Canvas Core 0.0.9 documentation

## Stacked Widget (stackedwidget)

# Stacked Widget (`stackedwidget`)

## AnimatedStackedWidget

A widget similar to `QStackedWidget` supporting animated transitions between widgets.

class `orangecanvas.gui.stackedwidget.` `AnimatedStackedWidget`(parent=None, animationEnabled=True)

  Bases: `PyQt5.QtWidgets.QFrame`

  `currentChanged`(int)

    Current widget has changed

  `transitionStarted`

    Transition animation has started

  `transitionFinished`

    Transition animation has finished

  `setAnimationEnabled`(animationEnabled)

    Enable/disable transition animations.

  `animationEnabled`()

    Is the transition animation enabled.

  `addWidget`(widget)

    Append the widget to the stack and return its index.

  `insertWidget`(index, widget)

    Insert widget into the stack at index.

  `removeWidget`(widget)

    Remove widget from the stack.

    Note

    The widget is hidden but is not deleted.

  `widget`(index)

    Return the widget at index

  `indexOf`(widget)

    Return the index of widget in the stack.

  `count`()

    Return the number of widgets in the stack.

  `setCurrentWidget`(widget)

    Set the current shown widget.

  `setCurrentIndex`(index)

    Set the current shown widget index.

  `currentIndex`()

    Return the current shown widget index.

class `orangecanvas.gui.stackedwidget.` `StackLayout`(parent=None)

  Bases: `PyQt5.QtWidgets.QStackedLayout`

  A stacked layout with `sizeHint` always the same as that of the current widget.